==> vlc-debug-1:3.0.23-3-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-b71bd03233a6a9392c906a22345041a9447bc49a/modules/gui/qt/medialibrary_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x54,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x8e,0x4,0x55,0xa,0x0,0x12,0x8a,0x20,0x19,0x60,0xd7,0x3,
  0x2b,0x21,0xa4,0xbb,0x84,0xda,0xc3,0x22,0xae,0x2b,0x0,0xb7,0x53,0x68,0x8b,0x53,
  0xe6,0x56,0x47,0xcb,0x10,0x6,0xde,0x14,0x42,0xf5,0xa2,0x4d,0x95,0x23,0x77,0xc3,
  0x7f,0x72,0x32,0xb,0xbe,0xe4,0x50,0x3f,0xed,0xc5,0x6f,0x63,0x88,0xb5,0x77,0x12,
  0x29,0xb4,0x9c,0x72,0x67,0xae,0xdc,0xb0,0xe4,0xcd,0x36,0xd7,0x8e,0x92,0xda,0x5a,
  0x52,0x8d,0x41,0xa8,0x83,0x6e,0xaf,0x4c,0x7a,0x56,0x66,0x36,0x6e,0xa2,0xfc,0xa5,
  0xca,0x98,0xd,0x40,0x8,0x6,0x81,0x8,0xbe,0x29,0x85,0x87,0xad,0x12,0xbe,0x12,
  0xbf,0x1,0xbc,0xf7,0x7c,0x6a,0xf,0x6b,0xaf,0x8,0xbe,0xaf,0x7e,0xb,0x74,0xf,
  0xbf,0x92,0xe,0x94,0xb1,0x1f,0x1,0x71,0xa8,0xa0,0x3d,0xc7,0x3a,0x3,0x6b,0xa8,
  0x21,0x57,0x98,0x49,0x51,0x2a,0x1b,0x73,0x20,0x44,0x68,0xad,0xda,0x1c,0x41,0x8,
  0x49,0x9,0x14,0x32,0x48,0x11,0x65,0xdc,0xba,0x6,0x40,0xde,0xb6,0x83,0x16,0xcb,
  0x64,0x79,0x2d,0x76,0x3c,0x6e,0xdc,0x6c,0x2c,0x71,0x22,0xd5,0xa1,0x90,0x72,0x51,
  0x63,0x38,0xbd,0x99,0x19,0xac,0x3c,0x48,0x9d,0x6a,0x45,0xef,0x9f,0xc1,0x3b,0xc9,
  0x68,0x20,0xbf,0xc,0xc4,0x52,0xef,0xba,0xb5,0x80,0x2e,0x8,0xe0,0x3b,0xc0,0xd0,
  0x61,0x17,0x9f,0x7d,0xc9,0x34,0xcc,0x36,0x13,0x3d,0x3e,0xaa,0xe8,0xe8,0x3f,0xc8,
  0x95,0x9e,0x7d,0x6e,0xde,0xbd,0x94,0xcc,0x1b,0x22,0x8a,0xd5,0x2d,0x60,0xd0,0x83,
  0x4,0xf3,0xa9,0x30,0x58,0x34,0x6d,0x7f,0x1c,0x24,0xa3,0x2e,0xed,0xb8,0x6c,0x65,
  0x5e,0xd7,0x22,0xd8,0x3d,0x73,0x51,0x77,0x83,0x62,0xa4,0xfa,0xa8,0x26,0x8e,0xbd,
  0x30,0xc4,0x6f,0xbf,0x6e,0xcc,0x29,0x8,0xfa,0xc1,0x38,0x2,0x24,0xcf,0x65,0xca,
  0xcf,0xfd,0xf2,0x72,0x75,0x5e,0x16,0x7f,0x9d,0xe5,0xa2,0x5a,0x81,0x86,0x0,0x39,
  0xe6,0xb9,0xb0,0xd0,0x33,0xaf,0x54,0x24,0xde,0xf7,0x1,0xef,0x82,0x28,0xba,0x83,
  0x0,0xb4,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // MediaLibrary
  0x0,0xc,
  0x8,0x8e,0xd6,0x59,
  0x0,0x4d,
  0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x61,0x0,0x4c,0x0,0x69,0x0,0x62,0x0,0x72,0x0,0x61,0x0,0x72,0x0,0x79,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml/VLC/MediaLibrary
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,
  // :/qt/qml/VLC/MediaLibrary/qmldir
  0x0,0x0,0x0,0x40,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xd5,0xdd,0x70,0xd0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> vlc-debug-1:3.0.23-4-x86_64.pkg.tar.zst: usr/src/debug/vlc/vlc-b71bd03233a6a9392c906a22345041a9447bc49a/modules/gui/qt/medialibrary_qmlassets.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x54,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x8e,0x4,0x55,0xa,0x0,0x12,0x8a,0x20,0x19,0x60,0xd7,0x3,
  0x2b,0x21,0xa4,0xbb,0x84,0xda,0xc3,0x22,0xae,0x2b,0x0,0xb7,0x53,0x68,0x8b,0x53,
  0xe6,0x56,0x47,0xcb,0x10,0x6,0xde,0x14,0x42,0xf5,0xa2,0x4d,0x95,0x23,0x77,0xc3,
  0x7f,0x72,0x32,0xb,0xbe,0xe4,0x50,0x3f,0xed,0xc5,0x6f,0x63,0x88,0xb5,0x77,0x12,
  0x29,0xb4,0x9c,0x72,0x67,0xae,0xdc,0xb0,0xe4,0xcd,0x36,0xd7,0x8e,0x92,0xda,0x5a,
  0x52,0x8d,0x41,0xa8,0x83,0x6e,0xaf,0x4c,0x7a,0x56,0x66,0x36,0x6e,0xa2,0xfc,0xa5,
  0xca,0x98,0xd,0x40,0x8,0x6,0x81,0x8,0xbe,0x29,0x85,0x87,0xad,0x12,0xbe,0x12,
  0xbf,0x1,0xbc,0xf7,0x7c,0x6a,0xf,0x6b,0xaf,0x8,0xbe,0xaf,0x7e,0xb,0x74,0xf,
  0xbf,0x92,0xe,0x94,0xb1,0x1f,0x1,0x71,0xa8,0xa0,0x3d,0xc7,0x3a,0x3,0x6b,0xa8,
  0x21,0x57,0x98,0x49,0x51,0x2a,0x1b,0x73,0x20,0x44,0x68,0xad,0xda,0x1c,0x41,0x8,
  0x49,0x9,0x14,0x32,0x48,0x11,0x65,0xdc,0xba,0x6,0x40,0xde,0xb6,0x83,0x16,0xcb,
  0x64,0x79,0x2d,0x76,0x3c,0x6e,0xdc,0x6c,0x2c,0x71,0x22,0xd5,0xa1,0x90,0x72,0x51,
  0x63,0x38,0xbd,0x99,0x19,0xac,0x3c,0x48,0x9d,0x6a,0x45,0xef,0x9f,0xc1,0x3b,0xc9,
  0x68,0x20,0xbf,0xc,0xc4,0x52,0xef,0xba,0xb5,0x80,0x2e,0x8,0xe0,0x3b,0xc0,0xd0,
  0x61,0x17,0x9f,0x7d,0xc9,0x34,0xcc,0x36,0x13,0x3d,0x3e,0xaa,0xe8,0xe8,0x3f,0xc8,
  0x95,0x9e,0x7d,0x6e,0xde,0xbd,0x94,0xcc,0x1b,0x22,0x8a,0xd5,0x2d,0x60,0xd0,0x83,
  0x4,0xf3,0xa9,0x30,0x58,0x34,0x6d,0x7f,0x1c,0x24,0xa3,0x2e,0xed,0xb8,0x6c,0x65,
  0x5e,0xd7,0x22,0xd8,0x3d,0x73,0x51,0x77,0x83,0x62,0xa4,0xfa,0xa8,0x26,0x8e,0xbd,
  0x30,0xc4,0x6f,0xbf,0x6e,0xcc,0x29,0x8,0xfa,0xc1,0x38,0x2,0x24,0xcf,0x65,0xca,
  0xcf,0xfd,0xf2,0x72,0x75,0x5e,0x16,0x7f,0x9d,0xe5,0xa2,0x5a,0x81,0x86,0x0,0x39,
  0xe6,0xb9,0xb0,0xd0,0x33,0xaf,0x54,0x24,0xde,0xf7,0x1,0xef,0x82,0x28,0xba,0x83,
  0x0,0xb4,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // VLC
  0x0,0x3,
  0x0,0x0,0x5b,0x3,
  0x0,0x56,
  0x0,0x4c,0x0,0x43,
    // MediaLibrary
  0x0,0xc,
  0x8,0x8e,0xd6,0x59,
  0x0,0x4d,
  0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x61,0x0,0x4c,0x0,0x69,0x0,0x62,0x0,0x72,0x0,0x61,0x0,0x72,0x0,0x79,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml/VLC
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml/VLC/MediaLibrary
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,
  // :/qt/qml/VLC/MediaLibrary/qmldir
  0x0,0x0,0x0,0x40,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9c,0x6,0x48,0x79,0xb8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_medialibrary_assets)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_medialibrary_assets)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
